@@ -44,10 +44,12 @@ class AIBS(AutoPathMixIn):
         self.AIBS_TENX_GENE_CHUNK_ZARR_PATH = AIBS_TENX_GENE_CHUNK_ZARR_PATH
         self.AIBS_TENX_GENE_CHUNK_V2_ZARR_PATH = AIBS_TENX_GENE_CHUNK_V2_ZARR_PATH
 
+        # Cluster level counts sum
         self.AIBS_SMART_CLUSTER_L4_SUM_ZARR_PATH = AIBS_SMART_CLUSTER_L4_SUM_ZARR_PATH
         self.AIBS_TENX_CLUSTER_L4_SUM_ZARR_PATH = AIBS_TENX_CLUSTER_L4_SUM_ZARR_PATH
         self.AIBS_SMART_CLUSTER_L4Region_SUM_ZARR_PATH = AIBS_SMART_CLUSTER_L4Region_SUM_ZARR_PATH
         self.AIBS_TENX_CLUSTER_L4Region_SUM_ZARR_PATH = AIBS_TENX_CLUSTER_L4Region_SUM_ZARR_PATH
+        self.AIBS_TENX_CLUSTER_V2_ANNOT_SUM_ZARR_PATH = AIBS_TENX_CLUSTER_V2_ANNOT_SUM_ZARR_PATH
 
         self.AIBS_TENX_CELL_TYPE_ANNOT_PALETTE_V2_PATH = AIBS_TENX_CELL_TYPE_ANNOT_PALETTE_V2_PATH
 
